const path = require('path');
const fs = require('fs-extra');
const glob = require('glob');
const autoprefixer = require('autoprefixer');
const postcss = require('postcss');
const postcssAtImport = require('postcss-import');
const postcssUrl = require('postcss-url');
const postcssMinify = require('postcss-minify');

const root = path.resolve(__dirname, '../../');
const srcDir = path.resolve(root, './src');
const distDir = path.resolve(root, './dist');
const buildDir = path.resolve(root, './.build');
const distDirIndex = path.resolve(root, './dist/index.css');

// Copy files from src/
fs.copy(srcDir, distDir, (err) => {
  if (err) return console.error(err);
  glob(path.resolve(distDir, '**/*.stories.js'), (err, files) => {
    if (err) return console.error(err);
    for (const file of files) {
      fs.removeSync(file);
    }
  });
  resolveIndexImports();
});

const resolveIndexImports = () => {
  fs.readFile(distDirIndex, (err, data) => {
    if (err) throw err;
    postcss([postcssAtImport, postcssUrl, postcssMinify, autoprefixer])
      .process(data.toString(), { from: distDirIndex, to: distDirIndex })
      .then((result) => {
        fs.outputFileSync(distDirIndex, result.css, () => true);
      });
  });
};

// Delete .build directory
fs.remove(buildDir, (err) => {
  if (err) return console.error(err);
});
